@@ -1,5 +1,9 @@
+from datetime import datetime
+from datetime import timedelta
+
 def delta2dict( delta ):
     """return dictionary of delta"""
+    delta = abs( delta )
     return { 
         'year'   : delta.days / 365 ,
         'day'    : delta.days % 365 ,
@@ -9,45 +13,28 @@ def delta2dict( delta ):
         'microsecond' : delta.microseconds
     }
 
-def delta2human( delta, precision = 2 ):
+def delta2human(delta, precision=2, past_format='{0} ago', future_format='in {0}'):
     """return human readable delta string"""
-    units = ( 'year', 'day', 'hour', 'minute', 'second', 'microsecond' )
+    the_format = past_format
+    if delta < timedelta(0): the_format = future_format
     d = delta2dict( delta )
     hlist = [] 
     count = 0
+    units = ( 'year', 'day', 'hour', 'minute', 'second', 'microsecond' )
     for unit in units:
         if count >= precision: break # met precision
         if d[ unit ] == 0: continue # skip 0's
         s = '' if d[ unit ] == 1 else 's' # handle plurals
         hlist.append( '%s %s%s' % ( d[unit], unit, s ) )
         count += 1
-    return ', '.join( hlist )
+    human_delta = ', '.join( hlist )
+    return the_format.format(human_delta) 
 
-def human( d1, precision = 2 ):
+def human(d, precision=2, format_past='{0} ago', format_future='in {0}'):
     """Pass datetime we will return human delta string"""
-    from datetime import datetime
-    d2 = datetime.now()
-    delta = d2 - d1
-    return delta2human( delta, precision ) 
-  
+    delta = datetime.now() - d
+    return delta2human( delta, precision, format_past, format_future ) 
 
-def test():
-    """Test and example usage"""
-    from datetime import datetime
-    d1 = datetime( 
-      year = 2009, 
-      month=5,
-      day=4,
-      hour=6,
-      minute=54,
-      second=33,
-      microsecond=4000
-     )
-    d2 = datetime.now()
-    delta = d2 - d1
-    print 'This is just the ago.py test:'
-    print delta2dict( delta )
-    print 'Commented ' + delta2human( delta, 3 ) + ' ago'
-    print 'Commented ' + human( d1 ) + ' ago'
-
-if __name__ == "__main__": test()
+if __name__ == "__main__": 
+    from test_ago import test_output
+    test_output()
